@@ -16,7 +16,7 @@
 #
 #  If we're running verbosely show a message, otherwise swallow it.
 #
-function logMessage
+logMessage ()
 {
     message="$*"
 
@@ -35,10 +35,15 @@ function logMessage
 #
 assert ()
 {
-    line=$1;
-    shift;
+    lineno="?"
 
-    if ! [ $* ] ; then
+    if [ -n "${LINENO}" ]; then
+    	# our shell defines variable LINENO, great!
+	lineno=$1
+	shift
+    fi
+
+    if [ ! $* ] ; then
         echo "assert failed: $0:$lineno [$*]"
 	exit
     fi
@@ -48,7 +53,7 @@ assert ()
 #
 #  Install a Debian package via apt-get.
 #
-function installDebianPackage
+installDebianPackage ()
 {
     prefix=$1
     package=$2
@@ -78,10 +83,42 @@ function installDebianPackage
 
 
 
+#
+#  Remove a Debian package.
+#
+removeDebianPackage ()
+{
+    prefix=$1
+    package=$2
+
+    #
+    # Log our options
+    #
+    logMessage "Purging Debian package ${package} from prefix ${prefix}"
+
+    #
+    #  We require a package + prefix
+    #
+    assert $LINENO "${package}"
+    assert $LINENO "${prefix}"
+
+    #
+    # Prefix must be a directory.
+    #
+    assert $LINENO -d ${prefix}
+
+    #
+    # Purge the package
+    #
+    chroot ${prefix} /usr/bin/dpkg --purge ${package}
+
+}
+
+
 #
 #  Install a CentOS4 package via yum
 #
-function installCentOS4Package
+installCentOS4Package ()
 {
     prefix=$1
     package=$2
@@ -114,7 +151,7 @@ function installCentOS4Package
 #
 # TODO: STUB
 #
-function installGentooPackage
+installGentooPackage ()
 {
     prefix=$1
     package=$2
